<?php
/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link https://getqurio.com/
 * @since 1.0.0
 * @package Qurio
 *
 * @wordpress-plugin
 * Plugin Name: Qurio
 * Plugin URI: https://www.getqurio.com/wordpress-plugin/
 * Description: With Qurio digital media can engage natively on their homepage with their audiences leveraging AI-powered surveys and engagement campaigns to boost trust, email signups, and revenue.
 * Version: 1.2.1
 * Author: AthensLive Media Solutions
 * Author URI: https://getqurio.com/
 * License: GPL-2.0+
 * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain: qurio-client-tool
 * Domain Path: /languages
 */

// If this file is called directly, abort.
if (!defined("WPINC")) {
    die();
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */

define("QURIO_VERSION", "1.2.1");

define("QURIO_SANDBOX", 1);

define("QURIO_LOG_FILE", WP_CONTENT_DIR . "/qurio-plugin-log.txt");

define("QURIO_DIRURL", plugin_dir_url(__FILE__));

define("QURIO_DIRPATH", plugin_dir_path(__FILE__));

define("QURIO_API_ROOT", "https://app.getqurio.com/api");

define("QURIO_APP_URL", "https://app.getqurio.com");

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-qurio-activator.php
 */

function qurio_activate()
{
    require_once plugin_dir_path(__FILE__) . "includes/class-qurio-activator.php";
    Qurio_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-qurio-deactivator.php
 */

function qurio_deactivate()
{
    require_once plugin_dir_path(__FILE__) . "includes/class-qurio-deactivator.php";
    Qurio_Deactivator::deactivate();
}

register_activation_hook(__FILE__, "qurio_activate");
register_deactivation_hook(__FILE__, "qurio_deactivate");

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */

require plugin_dir_path(__FILE__) . "includes/class-qurio.php";

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since 1.0.0
 */

function qurio_run()
{
    $plugin = new Qurio();
    $plugin->run();
}

function qurio_write_log($message, $level = "info")
{
    global $wp_filesystem;

    // Initialize the WP_Filesystem.
    if (!function_exists("WP_Filesystem")) {
        require_once ABSPATH . "wp-admin/includes/file.php";
    }

    WP_Filesystem();

    // Format the log entry
    $timestamp = current_time("mysql");
    $log_entry = "[{$timestamp}] [v" . QURIO_VERSION . "] [{$level}] {$message}" . PHP_EOL;

    // Append the log entry to current content.
    if ($wp_filesystem->exists(QURIO_LOG_FILE)) {
        $log_entry .= $wp_filesystem->get_contents(QURIO_LOG_FILE);
    }

    $wp_filesystem->put_contents(QURIO_LOG_FILE, $log_entry, FS_CHMOD_FILE);
}

qurio_run();
